pub trait CoerceShared<Target>: Reborrowwhere
Target: Copy,{ }🔬This is a nightly-only experimental API. (
reborrow #145612)Expand description
Allows reborrowable value to be reborrowed as shared, creating a copy that disables the source for writes for the lifetime of the copy.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".