Freeze

Trait Freeze 

pub unsafe auto trait Freeze { }
🔬This is a nightly-only experimental API. (freeze #121675)
Used to determine whether a type contains any UnsafeCell internally, but not through an indirection. This affects, for example, whether a static of that type is placed in read-only static memory or writable static memory. This can be used to declare that a constant with a generic type will not contain interior mutability, and subsequently allow placing the constant behind references.

Safety

This trait is a core part of the language, it is just expressed as a trait in libcore for convenience. Do not implement it for other types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> !Freeze for UnsafeCell<T>
where T: ?Sized,

Source

impl<T> Freeze for *const T is !null
where T: ?Sized,

Source

impl<T> Freeze for *const T
where T: ?Sized,

Source

impl<T> Freeze for *mut T is !null
where T: ?Sized,

Source

impl<T> Freeze for *mut T
where T: ?Sized,

Source

impl<T> Freeze for &T
where T: ?Sized,

Source

impl<T> Freeze for &mut T
where T: ?Sized,

1.28.0 · Source

impl<T> Freeze for NonZero<T>

Source

impl<T> Freeze for PhantomData<T>
where T: ?Sized,

Auto implementors



impl !Freeze for std::backtrace::Inner



impl !Freeze for Backtrace



impl !Freeze for Stash



impl !Freeze for Cache



impl !Freeze for Mapping



impl !Freeze for Barrier



impl !Freeze for std::sync::mpmc::context::Inner



impl !Freeze for Backoff



impl !Freeze for SyncWaker



impl !Freeze for std::sync::nonpoison::condvar::Condvar



impl !Freeze for std::sync::once::Once



impl !Freeze for std::sync::once::OnceState



impl !Freeze for Flag



impl !Freeze for Tid



impl !Freeze for std::sync::Condvar



impl !Freeze for std::sys::sync::condvar::futex::Condvar



impl !Freeze for std::sys::sync::mutex::futex::Mutex



impl !Freeze for std::sys::sync::once::futex::Once



impl !Freeze for std::sys::sync::once::futex::OnceState



impl !Freeze for std::sys::sync::rwlock::futex::RwLock



impl !Freeze for Parker



impl !Freeze for LazyKey



impl !Freeze for LocalPointer



impl !Freeze for ScopeData



impl !Freeze for std::thread::thread::Inner



impl<'a> !Freeze for Request<'a>



impl<'scope, T> !Freeze for std::thread::lifecycle::Packet<'scope, T>



impl<C> !Freeze for Counter<C>



impl<F> !Freeze for DlsymWeak<F>



impl<T> !Freeze for Cell<T>



impl<T> !Freeze for OnceCell<T>



impl<T> !Freeze for RefCell<T>



impl<T> !Freeze for SyncUnsafeCell<T>



impl<T> !Freeze for UnsafePinned<T>



impl<T> !Freeze for Atomic<T>



impl<T> !Freeze for std::sync::mpmc::array::Channel<T>



impl<T> !Freeze for std::sync::mpmc::array::Slot<T>



impl<T> !Freeze for Block<T>



impl<T> !Freeze for std::sync::mpmc::list::Channel<T>



impl<T> !Freeze for Position<T>



impl<T> !Freeze for std::sync::mpmc::list::Slot<T>



impl<T> !Freeze for std::sync::mpmc::zero::Channel<T>



impl<T> !Freeze for std::sync::mpmc::zero::Packet<T>



impl<T> !Freeze for std::sync::nonpoison::mutex::Mutex<T>



impl<T> !Freeze for std::sync::nonpoison::rwlock::RwLock<T>



impl<T> !Freeze for OnceLock<T>



impl<T> !Freeze for ReentrantLock<T>



impl<T> !Freeze for std::sync::Mutex<T>



impl<T> !Freeze for std::sync::RwLock<T>



impl<T> !Freeze for OnceBox<T>



impl<T> !Freeze for std::sys::thread_local::native::eager::Storage<T>



impl<T, D> !Freeze for std::sys::thread_local::native::lazy::Storage<T, D>



impl<T, F = fn() -> T> !Freeze for LazyCell<T, F>



impl<T, F = fn() -> T> !Freeze for LazyLock<T, F>



impl Freeze for AsciiChar



impl Freeze for BacktraceStatus



impl Freeze for BytesOrWide



impl Freeze for RawFrame



impl Freeze for std::backtrace_rs::backtrace::libunwind::Frame



impl Freeze for _Unwind_Context



impl Freeze for _Unwind_Reason_Code



impl Freeze for PrintFmt



impl Freeze for CharCase



impl Freeze for std::cmp::Ordering



impl Freeze for TryReserveErrorKind



impl Freeze for Infallible



impl Freeze for VarError



impl Freeze for FromBytesWithNulError



impl Freeze for c_void



impl Freeze for std::fmt::Alignment



impl Freeze for DebugAsHex



impl Freeze for Sign



impl Freeze for std::fs::TryLockError



impl Freeze for Locality



impl Freeze for AtomicOrdering



impl Freeze for BasicBlock



impl Freeze for UnwindTerminateReason



impl Freeze for SimdAlign



impl Freeze for ErrorKind



impl Freeze for SeekFrom



impl Freeze for Abi



impl Freeze for Generic



impl Freeze for TypeKind



impl Freeze for IpAddr



impl Freeze for Ipv6MulticastScope



impl Freeze for Shutdown



impl Freeze for std::net::SocketAddr



impl Freeze for FpCategory



impl Freeze for IntErrorKind



impl Freeze for OneSidedRangeBound



impl Freeze for AncillaryError



impl Freeze for BacktraceStyle



impl Freeze for Hook



impl Freeze for MustAbort



impl Freeze for std::path::State



impl Freeze for GetDisjointMutError



impl Freeze for SearchStep



impl Freeze for std::sync::atomic::Ordering



impl Freeze for Selected



impl Freeze for std::sync::mpsc::RecvTimeoutError



impl Freeze for std::sync::mpsc::TryRecvError



impl Freeze for OnceExclusiveState



impl Freeze for CopyState



impl Freeze for CopyResult



impl Freeze for FdHandle



impl Freeze for FdMeta



impl Freeze for SpliceMode



impl Freeze for EHAction



impl Freeze for ChildStdio



impl Freeze for ProgramKind



impl Freeze for std::sys::process::unix::common::Stdio



impl Freeze for Cgroup



impl Freeze for std::sys::thread_local::native::eager::State



impl Freeze for bool



impl Freeze for char



impl Freeze for f16



impl Freeze for f32



impl Freeze for f64



impl Freeze for f128



impl Freeze for i8



impl Freeze for i16



impl Freeze for i32



impl Freeze for i64



impl Freeze for i128



impl Freeze for isize



impl Freeze for !



impl Freeze for str



impl Freeze for u8



impl Freeze for u16



impl Freeze for u32



impl Freeze for u64



impl Freeze for u128



impl Freeze for ()



impl Freeze for usize



impl Freeze for AllocError



impl Freeze for Global



impl Freeze for Layout



impl Freeze for LayoutError



impl Freeze for System



impl Freeze for TypeId



impl Freeze for TryFromSliceError



impl Freeze for std::ascii::EscapeDefault



impl Freeze for BacktraceFrame



impl Freeze for BacktraceSymbol



impl Freeze for Capture



impl Freeze for Bomb



impl Freeze for std::backtrace_rs::backtrace::Frame



impl Freeze for ParsedSym



impl Freeze for CallbackData



impl Freeze for Mmap



impl Freeze for MapsEntry



impl Freeze for Library



impl Freeze for LibrarySegment



impl Freeze for std::backtrace_rs::symbolize::Symbol



impl Freeze for ByteStr



impl Freeze for ByteString



impl Freeze for BorrowError



impl Freeze for BorrowMutError



impl Freeze for CharTryFromError



impl Freeze for DecodeUtf16Error



impl Freeze for std::char::EscapeDebug



impl Freeze for std::char::EscapeDefault



impl Freeze for std::char::EscapeUnicode



impl Freeze for ParseCharError



impl Freeze for ToLowercase



impl Freeze for ToTitlecase



impl Freeze for ToUppercase



impl Freeze for TryFromCharError



impl Freeze for UnorderedKeyError



impl Freeze for TryReserveError



impl Freeze for std::env::Args



impl Freeze for ArgsOs



impl Freeze for std::env::JoinPathsError



impl Freeze for Vars



impl Freeze for VarsOs



impl Freeze for CStr



impl Freeze for CString



impl Freeze for FromBytesUntilNulError



impl Freeze for FromVecWithNulError



impl Freeze for IntoStringError



impl Freeze for NulError



impl Freeze for OsStr



impl Freeze for OsString



impl Freeze for std::fmt::Error



impl Freeze for FormattingOptions



impl Freeze for std::fs::Dir



impl Freeze for std::fs::DirBuilder



impl Freeze for std::fs::DirEntry



impl Freeze for std::fs::File



impl Freeze for std::fs::FileTimes



impl Freeze for std::fs::FileType



impl Freeze for Metadata



impl Freeze for std::fs::OpenOptions



impl Freeze for Permissions



impl Freeze for std::fs::ReadDir



impl Freeze for DefaultHasher



impl Freeze for RandomState



impl Freeze for SipHasher



impl Freeze for ReturnToArg



impl Freeze for UnwindActionArg



impl Freeze for Buffer



impl Freeze for WriterPanicked



impl Freeze for Repr



impl Freeze for Custom



impl Freeze for std::io::error::Error



impl Freeze for PipeReader



impl Freeze for PipeWriter



impl Freeze for std::io::stdio::Stderr



impl Freeze for StderrRaw



impl Freeze for std::io::stdio::Stdin



impl Freeze for StdinRaw



impl Freeze for std::io::stdio::Stdout



impl Freeze for StdoutRaw



impl Freeze for std::io::Empty



impl Freeze for std::io::Repeat



impl Freeze for Sink



impl Freeze for std::mem::Alignment



impl Freeze for Assume



impl Freeze for Array



impl Freeze for Bool



impl Freeze for Char



impl Freeze for Const



impl Freeze for DynTrait



impl Freeze for DynTraitPredicate



impl Freeze for Enum



impl Freeze for Field



impl Freeze for FieldId



impl Freeze for Float



impl Freeze for FnPtr



impl Freeze for GenericType



impl Freeze for Int



impl Freeze for Lifetime



impl Freeze for Pointer



impl Freeze for Reference



impl Freeze for std::mem::type_info::Slice



impl Freeze for Str



impl Freeze for Struct



impl Freeze for Trait



impl Freeze for Tuple



impl Freeze for Type



impl Freeze for std::mem::type_info::Union



impl Freeze for Variant



impl Freeze for AddrParseError



impl Freeze for Ipv4Addr



impl Freeze for Ipv6Addr



impl Freeze for SocketAddrV4



impl Freeze for SocketAddrV6



impl Freeze for IntoIncoming



impl Freeze for std::net::tcp::TcpListener



impl Freeze for std::net::tcp::TcpStream



impl Freeze for std::net::udp::UdpSocket



impl Freeze for ParseFloatError



impl Freeze for ParseIntError



impl Freeze for TryFromIntError



impl Freeze for RangeFull



impl Freeze for OwnedFd



impl Freeze for std::os::linux::process::PidFd



impl Freeze for stat



impl Freeze for std::os::unix::net::addr::SocketAddr



impl Freeze for SocketCred



impl Freeze for UnixDatagram



impl Freeze for UnixListener



impl Freeze for UnixStream



impl Freeze for UCred



impl Freeze for NormalizeError



impl Freeze for Path



impl Freeze for PathBuf



impl Freeze for StripPrefixError



impl Freeze for Child



impl Freeze for ChildStderr



impl Freeze for ChildStdin



impl Freeze for ChildStdout



impl Freeze for std::process::Command



impl Freeze for std::process::ExitCode



impl Freeze for std::process::ExitStatus



impl Freeze for std::process::ExitStatusError



impl Freeze for Output



impl Freeze for std::process::Stdio



impl Freeze for StdioPipes



impl Freeze for DefaultRandomSource



impl Freeze for ParseBoolError



impl Freeze for Utf8Error



impl Freeze for FromUtf8Error



impl Freeze for FromUtf16Error



impl Freeze for IntoChars



impl Freeze for String



impl Freeze for BarrierState



impl Freeze for BarrierWaitResult



impl Freeze for ArrayToken



impl Freeze for std::sync::mpmc::context::Context



impl Freeze for ListToken



impl Freeze for Operation



impl Freeze for Token



impl Freeze for std::sync::mpmc::waker::Entry



impl Freeze for std::sync::mpmc::waker::Waker



impl Freeze for std::sync::mpmc::zero::Inner



impl Freeze for ZeroToken



impl Freeze for RecvError



impl Freeze for WouldBlock



impl Freeze for std::sync::poison::Guard



impl Freeze for WaitTimeoutResult



impl Freeze for std::sys::args::common::Args



impl Freeze for Env



impl Freeze for FileDesc



impl Freeze for std::sys::fs::common::Dir



impl Freeze for CachedFileMetadata



impl Freeze for std::sys::fs::unix::dir::Dir



impl Freeze for std::sys::fs::unix::DirBuilder



impl Freeze for std::sys::fs::unix::DirEntry



impl Freeze for DirStream



impl Freeze for std::sys::fs::unix::File



impl Freeze for FileAttr



impl Freeze for FilePermissions



impl Freeze for std::sys::fs::unix::FileTimes



impl Freeze for std::sys::fs::unix::FileType



impl Freeze for InnerReadDir



impl Freeze for Mode



impl Freeze for std::sys::fs::unix::OpenOptions



impl Freeze for std::sys::fs::unix::ReadDir



impl Freeze for StatxExtraFields



impl Freeze for dirent64_min



impl Freeze for CopyParams



impl Freeze for LookupHost



impl Freeze for std::sys::net::connection::socket::TcpListener



impl Freeze for std::sys::net::connection::socket::TcpStream



impl Freeze for std::sys::net::connection::socket::UdpSocket



impl Freeze for Socket



impl Freeze for Buf



impl Freeze for std::sys::os_str::bytes::Slice



impl Freeze for std::sys::pal::unix::linux::pidfd::PidFd



impl Freeze for Handler



impl Freeze for ThreadInfo



impl Freeze for UnlockOnDrop



impl Freeze for Timespec



impl Freeze for std::sys::paths::unix::JoinPathsError



impl Freeze for DwarfReader



impl Freeze for CommandEnv



impl Freeze for CommandResolvedEnvs



impl Freeze for CStringArray



impl Freeze for ChildPipes



impl Freeze for std::sys::process::unix::common::Command



impl Freeze for std::sys::process::unix::common::ExitCode



impl Freeze for std::sys::process::unix::unix::ExitStatus



impl Freeze for std::sys::process::unix::unix::ExitStatusError



impl Freeze for Process



impl Freeze for std::sys::stdio::unix::Stderr



impl Freeze for std::sys::stdio::unix::Stdin



impl Freeze for std::sys::stdio::unix::Stdout



impl Freeze for std::sys::thread::unix::Thread



impl Freeze for std::sys::thread::unsupported::Thread



impl Freeze for std::sys::time::unix::Instant



impl Freeze for std::sys::time::unix::SystemTime



impl Freeze for LocalWaker



impl Freeze for RawWaker



impl Freeze for RawWakerVTable



impl Freeze for std::task::Waker



impl Freeze for Builder



impl Freeze for PanicGuard



impl Freeze for ThreadId



impl Freeze for ThreadInit



impl Freeze for AccessError



impl Freeze for ChildSpawnHooks



impl Freeze for SpawnHook



impl Freeze for SpawnHooks



impl Freeze for std::thread::thread::Thread



impl Freeze for ThreadNameString



impl Freeze for Duration



impl Freeze for std::time::Instant



impl Freeze for std::time::SystemTime



impl Freeze for SystemTimeError



impl Freeze for TryFromFloatSecsError



impl Freeze for PhantomPinned



impl Freeze for SocketAddrCRepr



impl<'a> Freeze for ResolveWhat<'a>



impl<'a> Freeze for std::backtrace_rs::symbolize::gimli::Symbol<'a>



impl<'a> Freeze for BytesOrWideString<'a>



impl<'a> Freeze for AddressKind<'a>



impl<'a> Freeze for AncillaryData<'a>



impl<'a> Freeze for Component<'a>



impl<'a> Freeze for Prefix<'a>



impl<'a> Freeze for Utf8Pattern<'a>



impl<'a> Freeze for Object<'a>



impl<'a> Freeze for std::backtrace_rs::symbolize::gimli::Context<'a>



impl<'a> Freeze for SymbolName<'a>



impl<'a> Freeze for SplitPaths<'a>



impl<'a> Freeze for std::ffi::os_str::Display<'a>



impl<'a> Freeze for VaList<'a>



impl<'a> Freeze for Arguments<'a>



impl<'a> Freeze for Formatter<'a>



impl<'a> Freeze for StderrLock<'a>



impl<'a> Freeze for StdinLock<'a>



impl<'a> Freeze for StdoutLock<'a>



impl<'a> Freeze for BorrowedCursor<'a>



impl<'a> Freeze for std::io::Guard<'a>



impl<'a> Freeze for std::io::IoSlice<'a>



impl<'a> Freeze for std::io::IoSliceMut<'a>



impl<'a> Freeze for std::net::tcp::Incoming<'a>



impl<'a> Freeze for Messages<'a>



impl<'a> Freeze for ScmCredentials<'a>



impl<'a> Freeze for ScmRights<'a>



impl<'a> Freeze for SocketAncillary<'a>



impl<'a> Freeze for std::os::unix::net::listener::Incoming<'a>



impl<'a> Freeze for Location<'a>



impl<'a> Freeze for PanicHookInfo<'a>



impl<'a> Freeze for Ancestors<'a>



impl<'a> Freeze for Components<'a>



impl<'a> Freeze for std::path::Display<'a>



impl<'a> Freeze for std::path::Iter<'a>



impl<'a> Freeze for PrefixComponent<'a>



impl<'a> Freeze for std::process::CommandArgs<'a>



impl<'a> Freeze for std::process::CommandEnvs<'a>



impl<'a> Freeze for EscapeAscii<'a>



impl<'a> Freeze for CharSearcher<'a>



impl<'a> Freeze for std::str::Bytes<'a>



impl<'a> Freeze for CharIndices<'a>



impl<'a> Freeze for Chars<'a>



impl<'a> Freeze for EncodeUtf16<'a>



impl<'a> Freeze for std::str::EscapeDebug<'a>



impl<'a> Freeze for std::str::EscapeDefault<'a>



impl<'a> Freeze for std::str::EscapeUnicode<'a>



impl<'a> Freeze for std::str::Lines<'a>



impl<'a> Freeze for LinesAny<'a>



impl<'a> Freeze for SplitAsciiWhitespace<'a>



impl<'a> Freeze for SplitWhitespace<'a>



impl<'a> Freeze for Utf8Chunk<'a>



impl<'a> Freeze for Utf8Chunks<'a>



impl<'a> Freeze for std::string::Drain<'a>



impl<'a> Freeze for BacktraceLock<'a>



impl<'a> Freeze for WStrUnits<'a>



impl<'a> Freeze for std::sys::io::io_slice::iovec::IoSlice<'a>



impl<'a> Freeze for std::sys::io::io_slice::iovec::IoSliceMut<'a>



impl<'a> Freeze for EHContext<'a>



impl<'a> Freeze for std::sys::process::env::CommandEnvs<'a>



impl<'a> Freeze for CStringIter<'a>



impl<'a> Freeze for std::sys::process::unix::common::CommandArgs<'a>



impl<'a> Freeze for CompletionGuard<'a>



impl<'a> Freeze for std::task::Context<'a>



impl<'a> Freeze for ContextBuilder<'a>



impl<'a> Freeze for PhantomContravariantLifetime<'a>



impl<'a> Freeze for PhantomCovariantLifetime<'a>



impl<'a> Freeze for PhantomInvariantLifetime<'a>



impl<'a, 'b> Freeze for BacktraceFmt<'a, 'b>



impl<'a, 'b> Freeze for DebugList<'a, 'b>



impl<'a, 'b> Freeze for DebugMap<'a, 'b>



impl<'a, 'b> Freeze for DebugSet<'a, 'b>



impl<'a, 'b> Freeze for DebugStruct<'a, 'b>



impl<'a, 'b> Freeze for DebugTuple<'a, 'b>



impl<'a, 'b> Freeze for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Freeze for StrSearcher<'a, 'b>



impl<'a, 'b, R, W> Freeze for Copier<'a, 'b, R, W>
where R: ?Sized, W: ?Sized,



impl<'a, 'b, const N: usize> Freeze for CharArrayRefSearcher<'a, 'b, N>



impl<'a, A> Freeze for std::option::Iter<'a, A>



impl<'a, A> Freeze for std::option::IterMut<'a, A>



impl<'a, B> Freeze for Cow<'a, B>
where <B as ToOwned>::Owned: Freeze, B: ?Sized,



impl<'a, D> Freeze for Indented<'a, D>



impl<'a, F> Freeze for CharPredicateSearcher<'a, F>
where F: Freeze,



impl<'a, I> Freeze for ByRefSized<'a, I>



impl<'a, I, A> Freeze for std::collections::vec_deque::Splice<'a, I, A>
where I: Freeze,



impl<'a, I, A> Freeze for std::vec::Splice<'a, I, A>
where I: Freeze,



impl<'a, K> Freeze for std::collections::btree_set::Cursor<'a, K>



impl<'a, K> Freeze for std::collections::hash::set::Iter<'a, K>



impl<'a, K, A> Freeze for std::collections::btree_set::CursorMut<'a, K, A>



impl<'a, K, A> Freeze for std::collections::btree_set::CursorMutKey<'a, K, A>



impl<'a, K, A> Freeze for std::collections::hash::set::Drain<'a, K, A>



impl<'a, K, F, A> Freeze for std::collections::hash::set::ExtractIf<'a, K, F, A>
where F: Freeze,



impl<'a, K, V> Freeze for std::collections::btree_map::Cursor<'a, K, V>



impl<'a, K, V> Freeze for std::collections::btree_map::Iter<'a, K, V>



impl<'a, K, V> Freeze for std::collections::btree_map::IterMut<'a, K, V>



impl<'a, K, V> Freeze for std::collections::btree_map::Keys<'a, K, V>



impl<'a, K, V> Freeze for std::collections::btree_map::Range<'a, K, V>



impl<'a, K, V> Freeze for RangeMut<'a, K, V>



impl<'a, K, V> Freeze for std::collections::btree_map::Values<'a, K, V>



impl<'a, K, V> Freeze for std::collections::btree_map::ValuesMut<'a, K, V>



impl<'a, K, V> Freeze for std::collections::hash::map::Iter<'a, K, V>



impl<'a, K, V> Freeze for std::collections::hash::map::IterMut<'a, K, V>



impl<'a, K, V> Freeze for std::collections::hash::map::Keys<'a, K, V>



impl<'a, K, V> Freeze for std::collections::hash::map::Values<'a, K, V>



impl<'a, K, V> Freeze for std::collections::hash::map::ValuesMut<'a, K, V>



impl<'a, K, V, A> Freeze for std::collections::btree_map::Entry<'a, K, V, A>
where K: Freeze, A: Freeze,



impl<'a, K, V, A> Freeze for std::collections::hash::map::Entry<'a, K, V, A>
where K: Freeze,



impl<'a, K, V, A> Freeze for std::collections::btree_map::CursorMut<'a, K, V, A>



impl<'a, K, V, A> Freeze for std::collections::btree_map::CursorMutKey<'a, K, V, A>



impl<'a, K, V, A> Freeze for std::collections::btree_map::OccupiedEntry<'a, K, V, A>
where A: Freeze,



impl<'a, K, V, A> Freeze for std::collections::btree_map::OccupiedError<'a, K, V, A>
where K: Freeze, V: Freeze, A: Freeze,



impl<'a, K, V, A> Freeze for std::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Freeze, A: Freeze,



impl<'a, K, V, A> Freeze for std::collections::hash::map::Drain<'a, K, V, A>



impl<'a, K, V, A> Freeze for std::collections::hash::map::OccupiedEntry<'a, K, V, A>



impl<'a, K, V, A> Freeze for std::collections::hash::map::OccupiedError<'a, K, V, A>
where K: Freeze, V: Freeze,



impl<'a, K, V, A> Freeze for std::collections::hash::map::VacantEntry<'a, K, V, A>
where K: Freeze,



impl<'a, K, V, F, A> Freeze for std::collections::hash::map::ExtractIf<'a, K, V, F, A>
where F: Freeze,



impl<'a, K, V, R, F, A> Freeze for std::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Freeze, A: Freeze, R: Freeze,



impl<'a, P> Freeze for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, P> Freeze for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Freeze,



impl<'a, T> Freeze for std::collections::binary_heap::Iter<'a, T>



impl<'a, T> Freeze for std::collections::btree_set::Iter<'a, T>



impl<'a, T> Freeze for std::collections::btree_set::Range<'a, T>



impl<'a, T> Freeze for std::collections::btree_set::SymmetricDifference<'a, T>



impl<'a, T> Freeze for std::collections::btree_set::Union<'a, T>



impl<'a, T> Freeze for std::collections::linked_list::Iter<'a, T>



impl<'a, T> Freeze for std::collections::linked_list::IterMut<'a, T>



impl<'a, T> Freeze for std::collections::vec_deque::Iter<'a, T>



impl<'a, T> Freeze for std::collections::vec_deque::IterMut<'a, T>



impl<'a, T> Freeze for AncillaryDataIter<'a, T>



impl<'a, T> Freeze for std::result::Iter<'a, T>



impl<'a, T> Freeze for std::result::IterMut<'a, T>



impl<'a, T> Freeze for Chunks<'a, T>



impl<'a, T> Freeze for ChunksExact<'a, T>



impl<'a, T> Freeze for ChunksExactMut<'a, T>



impl<'a, T> Freeze for ChunksMut<'a, T>



impl<'a, T> Freeze for std::slice::Iter<'a, T>



impl<'a, T> Freeze for std::slice::IterMut<'a, T>



impl<'a, T> Freeze for RChunks<'a, T>



impl<'a, T> Freeze for RChunksExact<'a, T>



impl<'a, T> Freeze for RChunksExactMut<'a, T>



impl<'a, T> Freeze for RChunksMut<'a, T>



impl<'a, T> Freeze for Windows<'a, T>



impl<'a, T> Freeze for std::sync::mpmc::Iter<'a, T>



impl<'a, T> Freeze for std::sync::mpmc::TryIter<'a, T>



impl<'a, T> Freeze for std::sync::mpsc::Iter<'a, T>



impl<'a, T> Freeze for std::sync::mpsc::TryIter<'a, T>



impl<'a, T> Freeze for std::sync::nonpoison::mutex::MappedMutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for std::sync::nonpoison::mutex::MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for ReentrantLockGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for std::sync::MappedMutexGuard<'a, T>
where T: ?Sized,



impl<'a, T> Freeze for std::sync::MutexGuard<'a, T>
where T: ?Sized,



impl<'a, T, A> Freeze for std::collections::btree_set::Entry<'a, T, A>
where A: Freeze, T: Freeze,



impl<'a, T, A> Freeze for std::collections::binary_heap::Drain<'a, T, A>



impl<'a, T, A> Freeze for DrainSorted<'a, T, A>



impl<'a, T, A> Freeze for std::collections::binary_heap::PeekMut<'a, T, A>



impl<'a, T, A> Freeze for std::collections::btree_set::Difference<'a, T, A>



impl<'a, T, A> Freeze for std::collections::btree_set::Intersection<'a, T, A>



impl<'a, T, A> Freeze for std::collections::btree_set::OccupiedEntry<'a, T, A>
where A: Freeze,



impl<'a, T, A> Freeze for std::collections::btree_set::VacantEntry<'a, T, A>
where T: Freeze, A: Freeze,



impl<'a, T, A> Freeze for std::collections::linked_list::Cursor<'a, T, A>



impl<'a, T, A> Freeze for std::collections::linked_list::CursorMut<'a, T, A>



impl<'a, T, A> Freeze for std::collections::vec_deque::Drain<'a, T, A>



impl<'a, T, A> Freeze for std::vec::Drain<'a, T, A>



impl<'a, T, A> Freeze for std::vec::PeekMut<'a, T, A>



impl<'a, T, F, A> Freeze for std::collections::linked_list::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, F, A> Freeze for std::collections::vec_deque::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, F, A> Freeze for std::vec::ExtractIf<'a, T, F, A>
where F: Freeze,



impl<'a, T, P> Freeze for ChunkBy<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for ChunkByMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for std::slice::RSplit<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for RSplitMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for std::slice::RSplitN<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for RSplitNMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for std::slice::Split<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for std::slice::SplitInclusive<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitInclusiveMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitMut<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for std::slice::SplitN<'a, T, P>
where P: Freeze,



impl<'a, T, P> Freeze for SplitNMut<'a, T, P>
where P: Freeze,



impl<'a, T, R, F, A> Freeze for std::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Freeze, A: Freeze, R: Freeze,



impl<'a, T, S, A> Freeze for std::collections::hash::set::Entry<'a, T, S, A>
where T: Freeze,



impl<'a, T, S, A> Freeze for std::collections::hash::set::Difference<'a, T, S, A>



impl<'a, T, S, A> Freeze for std::collections::hash::set::Intersection<'a, T, S, A>



impl<'a, T, S, A> Freeze for std::collections::hash::set::OccupiedEntry<'a, T, S, A>



impl<'a, T, S, A> Freeze for std::collections::hash::set::SymmetricDifference<'a, T, S, A>



impl<'a, T, S, A> Freeze for std::collections::hash::set::Union<'a, T, S, A>



impl<'a, T, S, A> Freeze for std::collections::hash::set::VacantEntry<'a, T, S, A>
where T: Freeze,



impl<'a, T, const N: usize> Freeze for ArrayWindows<'a, T, N>



impl<'a, W> Freeze for LineWriterShim<'a, W>
where W: ?Sized,



impl<'a, const N: usize> Freeze for CharArraySearcher<'a, N>



impl<'b, T> Freeze for Ref<'b, T>
where T: ?Sized,



impl<'b, T> Freeze for RefMut<'b, T>
where T: ?Sized,



impl<'data> Freeze for BorrowedBuf<'data>



impl<'fd> Freeze for BorrowedFd<'fd>



impl<'fmt, 'a, 'b> Freeze for BacktraceFrameFmt<'fmt, 'a, 'b>



impl<'rwlock, T> Freeze for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for std::sync::nonpoison::rwlock::RwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for std::sync::nonpoison::rwlock::RwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for std::sync::MappedRwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for std::sync::MappedRwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for std::sync::RwLockReadGuard<'rwlock, T>
where T: ?Sized,



impl<'rwlock, T> Freeze for std::sync::RwLockWriteGuard<'rwlock, T>
where T: ?Sized,



impl<'scope, 'env> Freeze for Scope<'scope, 'env>



impl<'scope, T> Freeze for JoinInner<'scope, T>



impl<'scope, T> Freeze for ScopedJoinHandle<'scope, T>



impl<A> Freeze for std::iter::Repeat<A>
where A: Freeze,



impl<A> Freeze for RepeatN<A>
where A: Freeze,



impl<A> Freeze for std::option::IntoIter<A>
where A: Freeze,



impl<A> Freeze for OptionFlatten<A>
where A: Freeze,



impl<A> Freeze for RangeFromIter<A>
where A: Freeze,



impl<A> Freeze for RangeInclusiveIter<A>
where A: Freeze,



impl<A> Freeze for RangeIter<A>
where A: Freeze,



impl<A, B> Freeze for Either<A, B>
where A: Freeze, B: Freeze,



impl<A, B> Freeze for std::iter::Chain<A, B>
where A: Freeze, B: Freeze,



impl<A, B> Freeze for Zip<A, B>
where A: Freeze, B: Freeze,



impl<B> Freeze for std::io::Lines<B>
where B: Freeze,



impl<B> Freeze for std::io::Split<B>
where B: Freeze,



impl<B, C> Freeze for ControlFlow<B, C>
where C: Freeze, B: Freeze,



impl<C> Freeze for ErrorData<C>
where C: Freeze,



impl<C> Freeze for std::sync::mpmc::counter::Receiver<C>



impl<C> Freeze for std::sync::mpmc::counter::Sender<C>



impl<D> Freeze for std::sys::thread_local::native::lazy::State<D>
where D: Freeze,



impl<Dyn> Freeze for DynMetadata<Dyn>
where Dyn: ?Sized,



impl<E> Freeze for Report<E>
where E: Freeze,



impl<F> Freeze for std::fmt::FromFn<F>
where F: Freeze,



impl<F> Freeze for PollFn<F>
where F: Freeze,



impl<F> Freeze for std::iter::FromFn<F>
where F: Freeze,



impl<F> Freeze for OnceWith<F>
where F: Freeze,



impl<F> Freeze for RepeatWith<F>
where F: Freeze,



impl<F> Freeze for ExternWeak<F>
where F: Freeze,



impl<G> Freeze for FromCoroutine<G>
where G: Freeze,



impl<H> Freeze for BuildHasherDefault<H>



impl<I> Freeze for FromIter<I>
where I: Freeze,



impl<I> Freeze for DecodeUtf16<I>
where I: Freeze,



impl<I> Freeze for Cloned<I>
where I: Freeze,



impl<I> Freeze for Copied<I>
where I: Freeze,



impl<I> Freeze for Cycle<I>
where I: Freeze,



impl<I> Freeze for Enumerate<I>
where I: Freeze,



impl<I> Freeze for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Freeze, I: Freeze,



impl<I> Freeze for Fuse<I>
where I: Freeze,



impl<I> Freeze for Intersperse<I>
where <I as Iterator>::Item: Sized + Freeze, I: Freeze,



impl<I> Freeze for Peekable<I>
where I: Freeze, <I as Iterator>::Item: Freeze,



impl<I> Freeze for Skip<I>
where I: Freeze,



impl<I> Freeze for StepBy<I>
where I: Freeze,



impl<I> Freeze for std::iter::Take<I>
where I: Freeze,



impl<I, F> Freeze for FilterMap<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Inspect<I, F>
where I: Freeze, F: Freeze,



impl<I, F> Freeze for Map<I, F>
where I: Freeze, F: Freeze,



impl<I, F, const N: usize> Freeze for MapWindows<I, F, N>
where F: Freeze, I: Freeze, <I as Iterator>::Item: Freeze,



impl<I, G> Freeze for IntersperseWith<I, G>
where G: Freeze, I: Freeze, <I as Iterator>::Item: Freeze,



impl<I, P> Freeze for Filter<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for MapWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for SkipWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, P> Freeze for TakeWhile<I, P>
where I: Freeze, P: Freeze,



impl<I, St, F> Freeze for Scan<I, St, F>
where I: Freeze, F: Freeze, St: Freeze,



impl<I, U, F> Freeze for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Freeze, I: Freeze, F: Freeze,



impl<I, const N: usize> Freeze for ArrayChunks<I, N>
where I: Freeze, <I as Iterator>::Item: Freeze,



impl<Idx> Freeze for std::ops::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for std::ops::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for std::ops::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for RangeTo<Idx>
where Idx: Freeze,



impl<Idx> Freeze for std::ops::RangeToInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for std::range::Range<Idx>
where Idx: Freeze,



impl<Idx> Freeze for std::range::RangeFrom<Idx>
where Idx: Freeze,



impl<Idx> Freeze for std::range::RangeInclusive<Idx>
where Idx: Freeze,



impl<Idx> Freeze for std::range::RangeToInclusive<Idx>
where Idx: Freeze,



impl<K, A> Freeze for std::collections::hash::set::IntoIter<K, A>
where A: Freeze,



impl<K, V, A> Freeze for std::collections::btree_map::IntoIter<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for std::collections::btree_map::IntoKeys<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for std::collections::btree_map::IntoValues<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for std::collections::hash::map::IntoIter<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for std::collections::hash::map::IntoKeys<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for std::collections::hash::map::IntoValues<K, V, A>
where A: Freeze,



impl<K, V, A> Freeze for BTreeMap<K, V, A>
where A: Freeze,



impl<K, V, S, A> Freeze for HashMap<K, V, S, A>
where S: Freeze, A: Freeze,



impl<P> Freeze for MaybeDangling<P>
where P: Freeze + ?Sized,



impl<Ptr> Freeze for Pin<Ptr>
where Ptr: Freeze,



impl<R> Freeze for BufReader<R>
where R: Freeze + ?Sized,



impl<R> Freeze for std::io::Bytes<R>
where R: Freeze,



impl<Ret, T> Freeze for fn(T₁, T₂, …, Tₙ) -> Ret



impl<T> Freeze for Bound<T>
where T: Freeze,



impl<T> Freeze for Option<T>
where T: Freeze,



impl<T> Freeze for std::sync::TryLockError<T>
where T: Freeze,



impl<T> Freeze for ReceiverFlavor<T>



impl<T> Freeze for SenderFlavor<T>



impl<T> Freeze for SendTimeoutError<T>
where T: Freeze,



impl<T> Freeze for TrySendError<T>
where T: Freeze,



impl<T> Freeze for std::sync::oneshot::RecvTimeoutError<T>



impl<T> Freeze for std::sync::oneshot::TryRecvError<T>



impl<T> Freeze for Poll<T>
where T: Freeze,



impl<T> Freeze for [T]
where T: Freeze,



impl<T> Freeze for (T₁, T₂, …, Tₙ)
where T: Freeze,



impl<T> Freeze for ThinBox<T>
where T: ?Sized,



impl<T> Freeze for Reverse<T>
where T: Freeze,



impl<T> Freeze for Pending<T>



impl<T> Freeze for Ready<T>
where T: Freeze,



impl<T> Freeze for std::io::Cursor<T>
where T: Freeze,



impl<T> Freeze for std::io::Take<T>
where T: Freeze,



impl<T> Freeze for std::iter::Empty<T>



impl<T> Freeze for std::iter::Once<T>
where T: Freeze,



impl<T> Freeze for Rev<T>
where T: Freeze,



impl<T> Freeze for Discriminant<T>



impl<T> Freeze for ManuallyDrop<T>
where T: Freeze + ?Sized,



impl<T> Freeze for TraitImpl<T>
where T: ?Sized,



impl<T> Freeze for Saturating<T>
where T: Freeze,



impl<T> Freeze for Wrapping<T>
where T: Freeze,



impl<T> Freeze for Yeet<T>
where T: Freeze,



impl<T> Freeze for AssertUnwindSafe<T>
where T: Freeze,



impl<T> Freeze for NonNull<T>
where T: ?Sized,



impl<T> Freeze for std::result::IntoIter<T>
where T: Freeze,



impl<T> Freeze for std::sync::mpmc::IntoIter<T>



impl<T> Freeze for std::sync::mpmc::Receiver<T>



impl<T> Freeze for std::sync::mpmc::Sender<T>



impl<T> Freeze for CachePadded<T>
where T: Freeze,



impl<T> Freeze for std::sync::mpsc::IntoIter<T>



impl<T> Freeze for std::sync::mpsc::Receiver<T>



impl<T> Freeze for SendError<T>
where T: Freeze,



impl<T> Freeze for std::sync::mpsc::Sender<T>



impl<T> Freeze for SyncSender<T>



impl<T> Freeze for std::sync::oneshot::Receiver<T>



impl<T> Freeze for std::sync::oneshot::Sender<T>



impl<T> Freeze for PoisonError<T>
where T: Freeze,



impl<T> Freeze for SyncView<T>
where T: Freeze + ?Sized,



impl<T> Freeze for JoinHandle<T>



impl<T> Freeze for LocalKey<T>



impl<T> Freeze for PhantomContravariant<T>
where T: ?Sized,



impl<T> Freeze for PhantomCovariant<T>
where T: ?Sized,



impl<T> Freeze for PhantomInvariant<T>
where T: ?Sized,



impl<T> Freeze for MaybeUninit<T>
where T: Freeze,



impl<T, A> Freeze for Box<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for std::collections::binary_heap::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for IntoIterSorted<T, A>
where A: Freeze,



impl<T, A> Freeze for std::collections::btree_set::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for std::collections::linked_list::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for BTreeSet<T, A>
where A: Freeze,



impl<T, A> Freeze for BinaryHeap<T, A>
where A: Freeze,



impl<T, A> Freeze for LinkedList<T, A>
where A: Freeze,



impl<T, A> Freeze for VecDeque<T, A>
where A: Freeze,



impl<T, A> Freeze for std::collections::vec_deque::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for Rc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueRc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for std::rc::Weak<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for Arc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for UniqueArc<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for std::sync::Weak<T, A>
where A: Freeze, T: ?Sized,



impl<T, A> Freeze for std::vec::IntoIter<T, A>
where A: Freeze,



impl<T, A> Freeze for Vec<T, A>
where A: Freeze,



impl<T, E> Freeze for Result<T, E>
where T: Freeze, E: Freeze,



impl<T, F> Freeze for Successors<T, F>
where F: Freeze, T: Freeze,



impl<T, F> Freeze for DropGuard<T, F>
where T: Freeze, F: Freeze,



impl<T, F> Freeze for Data<T, F>
where T: Freeze, F: Freeze,



impl<T, S, A> Freeze for HashSet<T, S, A>
where S: Freeze, A: Freeze,



impl<T, U> Freeze for std::io::Chain<T, U>
where T: Freeze, U: Freeze,



impl<T, const N: usize> Freeze for [T; N]
where T: Freeze,



impl<T, const N: usize> Freeze for std::array::IntoIter<T, N>
where T: Freeze,



impl<T, const N: usize> Freeze for Lru<T, N>
where T: Freeze,



impl<T, const N: usize> Freeze for Mask<T, N>
where T: Freeze,



impl<T, const N: usize> Freeze for Simd<T, N>
where T: Freeze,



impl<T, const N: usize> Freeze for [Option<T>; N]
where T: Freeze,



impl<T, const N: usize> Freeze for [MaybeUninit<T>; N]
where T: Freeze,



impl<T, const VARIANT: u32, const FIELD: u32> Freeze for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<W> Freeze for BufWriter<W>
where W: Freeze + ?Sized,



impl<W> Freeze for LineWriter<W>
where W: Freeze + ?Sized,



impl<W> Freeze for IntoInnerError<W>
where W: Freeze,



impl<Y, R> Freeze for CoroutineState<Y, R>
where Y: Freeze, R: Freeze,



impl<const N: usize> Freeze for [u8; N]