pub trait Reborrow { }🔬This is a nightly-only experimental API. (
reborrow #145612)Expand description
Allows value to be reborrowed as exclusive, creating a copy of the value that disables the source for reads and writes for the lifetime of the copy.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".