Send

Trait Send 

1.0.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.26.0 · Source

impl !Send for std::env::Args

1.26.0 · Source

impl !Send for ArgsOs

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for std::sys::args::common::Args

Available on target_family=windows, or Hermit, or Motor OS, or UEFI, or WASI, or Xous, or target_family=unix and neither ESP-IDF nor Play Station Vita only.
Source

impl !Send for Env

Available on target_family=unix, or Hermit, or Motor OS, or SOLID ASP3, or UEFI, or WASI, or Xous, or Fortanix and SGX only.
Source

impl !Send for LocalWaker

1.0.0 · Source

impl<T> !Send for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for *mut T
where T: ?Sized,

1.25.0 · Source

impl<T> !Send for NonNull<T>
where T: ?Sized,

NonNull pointers are not Send because the data they reference may be aliased.

1.0.0 · Source

impl<T, A> !Send for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Send for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Send for std::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T: ?Sized> !Send for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>

Source

impl<T: ?Sized> !Send for std::sync::nonpoison::mutex::MutexGuard<'_, T>

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

Source

impl<T: ?Sized> !Send for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>

Source

impl<T: ?Sized> !Send for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>

Source

impl<T: ?Sized> !Send for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>

Source

impl<T: ?Sized> !Send for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>

Source

impl<T: ?Sized> !Send for ReentrantLockGuard<'_, T>

Source

impl<T: ?Sized> !Send for std::sync::MappedMutexGuard<'_, T>

Source

impl<T: ?Sized> !Send for std::sync::MappedRwLockReadGuard<'_, T>

Source

impl<T: ?Sized> !Send for std::sync::MappedRwLockWriteGuard<'_, T>

1.0.0 · Source

impl<T: ?Sized> !Send for std::sync::MutexGuard<'_, T>

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

1.0.0 · Source

impl<T: ?Sized> !Send for std::sync::RwLockReadGuard<'_, T>

1.0.0 · Source

impl<T: ?Sized> !Send for std::sync::RwLockWriteGuard<'_, T>

Source

impl Send for std::backtrace_rs::backtrace::libunwind::Frame

Source

impl Send for core::ffi::c_str::Bytes<'_>

1.0.0 · Source

impl Send for TypeId

Source

impl Send for ResumeTy

Source

impl Send for Repr

Available on 64-bit and non-UEFI only.
1.10.0 · Source

impl Send for Location<'_>

1.6.0 · Source

impl Send for std::string::Drain<'_>

Source

impl Send for DirStream

Source

impl Send for LookupHost

Source

impl Send for CStringArray

Source

impl Send for std::sys::thread::unix::Thread

1.36.0 · Source

impl Send for std::task::Waker

1.44.0 · Source

impl<'a> Send for std::io::IoSlice<'a>

1.44.0 · Source

impl<'a> Send for std::io::IoSliceMut<'a>

Source

impl<Dyn> Send for DynMetadata<Dyn>
where Dyn: ?Sized,

Source

impl<F> Send for DlsymWeak<F>

Available on GNU and Linux only.
1.0.0 · Source

impl<T> Send for &T
where T: Sync + ?Sized,

Source

impl<T> Send for ThinBox<T>
where T: Send + ?Sized,

ThinBox<T> is Send if T is Send because the data is owned.

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for std::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for std::collections::linked_list::IterMut<'_, T>
where T: Send,

1.28.0 · Source

impl<T> Send for NonZero<T>

Source

impl<T> Send for Unique<T>
where T: Send + ?Sized,

Unique pointers are Send if T is Send because the data they reference is unaliased. Note that this aliasing invariant is unenforced by the type system; the abstraction using the Unique must enforce it.

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::slice::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for std::slice::IterMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for Atomic<T>
where T: AtomicPrimitive,

1.29.0 · Source

impl<T> Send for JoinHandle<T>

Source

impl<T, A> Send for std::collections::linked_list::Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Send for std::collections::linked_list::CursorMut<'_, T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for LinkedList<T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for std::collections::vec_deque::Drain<'_, T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

Source

impl<T, A> Send for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

1.4.0 · Source

impl<T, A> Send for std::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for std::vec::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

1.0.0 · Source

impl<T, A> Send for std::vec::IntoIter<T, A>
where T: Send, A: Allocator + Send,

Source

impl<T: Send + ?Sized> Send for ReentrantLock<T>

Source

impl<T: Send> Send for std::sync::mpmc::Receiver<T>

Source

impl<T: Send> Send for std::sync::mpmc::Sender<T>

1.0.0 · Source

impl<T: Send> Send for std::sync::mpsc::Receiver<T>

1.0.0 · Source

impl<T: Send> Send for std::sync::mpsc::Sender<T>

1.0.0 · Source

impl<T: Send> Send for SyncSender<T>

1.70.0 · Source

impl<T: Send> Send for OnceLock<T>

Source

impl<T: Send> Send for OnceBox<T>

Source

impl<T: ?Sized + Send> Send for std::sync::nonpoison::mutex::Mutex<T>

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

Source

impl<T: ?Sized + Send> Send for std::sync::nonpoison::rwlock::RwLock<T>

1.0.0 · Source

impl<T: ?Sized + Send> Send for std::sync::Mutex<T>

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

1.0.0 · Source

impl<T: ?Sized + Send> Send for std::sync::RwLock<T>

Auto implementors



impl !Send for EHAction



impl !Send for Mmap



impl !Send for Stash



impl !Send for Cache



impl !Send for Mapping



impl !Send for std::backtrace_rs::symbolize::Symbol



impl !Send for Vars



impl !Send for VarsOs



impl !Send for ArrayToken



impl !Send for ListToken



impl !Send for Token



impl !Send for std::sync::mpmc::waker::Entry



impl !Send for SyncWaker



impl !Send for std::sync::mpmc::waker::Waker



impl !Send for std::sync::mpmc::zero::Inner



impl !Send for ZeroToken



impl !Send for Handler



impl !Send for DwarfReader



impl !Send for LocalPointer



impl !Send for RawWaker



impl<'a> !Send for ResolveWhat<'a>



impl<'a> !Send for std::backtrace_rs::symbolize::gimli::Symbol<'a>



impl<'a> !Send for Request<'a>



impl<'a> !Send for VaList<'a>



impl<'a> !Send for Formatter<'a>



impl<'a> !Send for StderrLock<'a>



impl<'a> !Send for StdinLock<'a>



impl<'a> !Send for StdoutLock<'a>



impl<'a> !Send for PanicHookInfo<'a>



impl<'a> !Send for std::process::CommandArgs<'a>



impl<'a> !Send for BacktraceLock<'a>



impl<'a> !Send for WStrUnits<'a>



impl<'a> !Send for std::sys::io::io_slice::iovec::IoSlice<'a>



impl<'a> !Send for std::sys::io::io_slice::iovec::IoSliceMut<'a>



impl<'a> !Send for EHContext<'a>



impl<'a> !Send for CStringIter<'a>



impl<'a> !Send for std::sys::process::unix::common::CommandArgs<'a>



impl<'a> !Send for std::task::Context<'a>



impl<'a> !Send for ContextBuilder<'a>



impl<'a, 'b> !Send for BacktraceFmt<'a, 'b>



impl<'a, 'b> !Send for DebugList<'a, 'b>



impl<'a, 'b> !Send for DebugMap<'a, 'b>



impl<'a, 'b> !Send for DebugSet<'a, 'b>



impl<'a, 'b> !Send for DebugStruct<'a, 'b>



impl<'a, 'b> !Send for DebugTuple<'a, 'b>



impl<'a, T> !Send for std::sync::mpsc::Iter<'a, T>



impl<'a, T> !Send for std::sync::mpsc::TryIter<'a, T>



impl<'a, T, F, A = Global> !Send for std::collections::linked_list::ExtractIf<'a, T, F, A>



impl<'b, T> !Send for Ref<'b, T>



impl<'b, T> !Send for RefMut<'b, T>



impl<'fmt, 'a, 'b> !Send for BacktraceFrameFmt<'fmt, 'a, 'b>



impl<C> !Send for std::sync::mpmc::counter::Receiver<C>



impl<C> !Send for std::sync::mpmc::counter::Sender<C>



impl<T> !Send for ReceiverFlavor<T>



impl<T> !Send for SenderFlavor<T>



impl<T> !Send for std::sync::mpmc::array::Channel<T>



impl<T> !Send for std::sync::mpmc::list::Channel<T>



impl<T> !Send for std::sync::mpmc::zero::Channel<T>



impl Send for AsciiChar



impl Send for BacktraceStatus



impl Send for BytesOrWide



impl Send for std::backtrace::Inner



impl Send for RawFrame



impl Send for _Unwind_Context



impl Send for _Unwind_Reason_Code



impl Send for PrintFmt



impl Send for CharCase



impl Send for std::cmp::Ordering



impl Send for TryReserveErrorKind



impl Send for Infallible



impl Send for VarError



impl Send for FromBytesWithNulError



impl Send for c_void



impl Send for std::fmt::Alignment



impl Send for DebugAsHex



impl Send for Sign



impl Send for std::fs::TryLockError



impl Send for Locality



impl Send for AtomicOrdering



impl Send for BasicBlock



impl Send for UnwindTerminateReason



impl Send for SimdAlign



impl Send for ErrorKind



impl Send for SeekFrom



impl Send for Abi



impl Send for Generic



impl Send for TypeKind



impl Send for IpAddr



impl Send for Ipv6MulticastScope



impl Send for Shutdown



impl Send for std::net::SocketAddr



impl Send for FpCategory



impl Send for IntErrorKind



impl Send for OneSidedRangeBound



impl Send for AncillaryError



impl Send for BacktraceStyle



impl Send for Hook



impl Send for MustAbort



impl Send for std::path::State



impl Send for GetDisjointMutError



impl Send for SearchStep



impl Send for std::sync::atomic::Ordering



impl Send for Selected



impl Send for std::sync::mpsc::RecvTimeoutError



impl Send for std::sync::mpsc::TryRecvError



impl Send for OnceExclusiveState



impl Send for CopyState



impl Send for CopyResult



impl Send for FdHandle



impl Send for FdMeta



impl Send for SpliceMode



impl Send for ChildStdio



impl Send for ProgramKind



impl Send for std::sys::process::unix::common::Stdio



impl Send for Cgroup



impl Send for std::sys::thread_local::native::eager::State



impl Send for bool



impl Send for char



impl Send for f16



impl Send for f32



impl Send for f64



impl Send for f128



impl Send for i8



impl Send for i16



impl Send for i32



impl Send for i64



impl Send for i128



impl Send for isize



impl Send for !



impl Send for str



impl Send for u8



impl Send for u16



impl Send for u32



impl Send for u64



impl Send for u128



impl Send for ()



impl Send for usize



impl Send for AllocError



impl Send for Global



impl Send for Layout



impl Send for LayoutError



impl Send for System



impl Send for TryFromSliceError



impl Send for std::ascii::EscapeDefault



impl Send for Backtrace



impl Send for BacktraceFrame



impl Send for BacktraceSymbol



impl Send for Capture



impl Send for Bomb



impl Send for std::backtrace_rs::backtrace::Frame



impl Send for ParsedSym



impl Send for CallbackData



impl Send for MapsEntry



impl Send for Library



impl Send for LibrarySegment



impl Send for ByteStr



impl Send for ByteString



impl Send for BorrowError



impl Send for BorrowMutError



impl Send for CharTryFromError



impl Send for DecodeUtf16Error



impl Send for std::char::EscapeDebug



impl Send for std::char::EscapeDefault



impl Send for std::char::EscapeUnicode



impl Send for ParseCharError



impl Send for ToLowercase



impl Send for ToTitlecase



impl Send for ToUppercase



impl Send for TryFromCharError



impl Send for UnorderedKeyError



impl Send for TryReserveError



impl Send for std::env::JoinPathsError



impl Send for CStr



impl Send for CString



impl Send for FromBytesUntilNulError



impl Send for FromVecWithNulError



impl Send for IntoStringError



impl Send for NulError



impl Send for OsStr



impl Send for OsString



impl Send for std::fmt::Error



impl Send for FormattingOptions



impl Send for std::fs::Dir



impl Send for std::fs::DirBuilder



impl Send for std::fs::DirEntry



impl Send for std::fs::File



impl Send for std::fs::FileTimes



impl Send for std::fs::FileType



impl Send for Metadata



impl Send for std::fs::OpenOptions



impl Send for Permissions



impl Send for std::fs::ReadDir



impl Send for DefaultHasher



impl Send for RandomState



impl Send for SipHasher



impl Send for ReturnToArg



impl Send for UnwindActionArg



impl Send for Buffer



impl Send for WriterPanicked



impl Send for Custom



impl Send for std::io::error::Error



impl Send for PipeReader



impl Send for PipeWriter



impl Send for std::io::stdio::Stderr



impl Send for StderrRaw



impl Send for std::io::stdio::Stdin



impl Send for StdinRaw



impl Send for std::io::stdio::Stdout



impl Send for StdoutRaw



impl Send for std::io::Empty



impl Send for std::io::Repeat



impl Send for Sink



impl Send for std::mem::Alignment



impl Send for Assume



impl Send for Array



impl Send for Bool



impl Send for Char



impl Send for Const



impl Send for DynTrait



impl Send for DynTraitPredicate



impl Send for Enum



impl Send for Field



impl Send for FieldId



impl Send for Float



impl Send for FnPtr



impl Send for GenericType



impl Send for Int



impl Send for Lifetime



impl Send for Pointer



impl Send for Reference



impl Send for std::mem::type_info::Slice



impl Send for Str



impl Send for Struct



impl Send for Trait



impl Send for Tuple



impl Send for Type



impl Send for std::mem::type_info::Union



impl Send for Variant



impl Send for AddrParseError



impl Send for Ipv4Addr



impl Send for Ipv6Addr



impl Send for SocketAddrV4



impl Send for SocketAddrV6



impl Send for IntoIncoming



impl Send for std::net::tcp::TcpListener



impl Send for std::net::tcp::TcpStream



impl Send for std::net::udp::UdpSocket



impl Send for ParseFloatError



impl Send for ParseIntError



impl Send for TryFromIntError



impl Send for RangeFull



impl Send for OwnedFd



impl Send for std::os::linux::process::PidFd



impl Send for stat



impl Send for std::os::unix::net::addr::SocketAddr



impl Send for SocketCred



impl Send for UnixDatagram



impl Send for UnixListener



impl Send for UnixStream



impl Send for UCred



impl Send for NormalizeError



impl Send for Path



impl Send for PathBuf



impl Send for StripPrefixError



impl Send for Child



impl Send for ChildStderr



impl Send for ChildStdin



impl Send for ChildStdout



impl Send for std::process::Command



impl Send for std::process::ExitCode



impl Send for std::process::ExitStatus



impl Send for std::process::ExitStatusError



impl Send for Output



impl Send for std::process::Stdio



impl Send for StdioPipes



impl Send for DefaultRandomSource



impl Send for ParseBoolError



impl Send for Utf8Error



impl Send for FromUtf8Error



impl Send for FromUtf16Error



impl Send for IntoChars



impl Send for String



impl Send for Barrier



impl Send for BarrierState



impl Send for BarrierWaitResult



impl Send for std::sync::mpmc::context::Context



impl Send for std::sync::mpmc::context::Inner



impl Send for Operation



impl Send for Backoff



impl Send for RecvError



impl Send for std::sync::nonpoison::condvar::Condvar



impl Send for WouldBlock



impl Send for std::sync::once::Once



impl Send for std::sync::once::OnceState



impl Send for Flag



impl Send for std::sync::poison::Guard



impl Send for Tid



impl Send for std::sync::Condvar



impl Send for WaitTimeoutResult



impl Send for FileDesc



impl Send for std::sys::fs::common::Dir



impl Send for CachedFileMetadata



impl Send for std::sys::fs::unix::dir::Dir



impl Send for std::sys::fs::unix::DirBuilder



impl Send for std::sys::fs::unix::DirEntry



impl Send for std::sys::fs::unix::File



impl Send for FileAttr



impl Send for FilePermissions



impl Send for std::sys::fs::unix::FileTimes



impl Send for std::sys::fs::unix::FileType



impl Send for InnerReadDir



impl Send for Mode



impl Send for std::sys::fs::unix::OpenOptions



impl Send for std::sys::fs::unix::ReadDir



impl Send for StatxExtraFields



impl Send for dirent64_min



impl Send for CopyParams



impl Send for std::sys::net::connection::socket::TcpListener



impl Send for std::sys::net::connection::socket::TcpStream



impl Send for std::sys::net::connection::socket::UdpSocket



impl Send for Socket



impl Send for Buf



impl Send for std::sys::os_str::bytes::Slice



impl Send for std::sys::pal::unix::linux::pidfd::PidFd



impl Send for ThreadInfo



impl Send for UnlockOnDrop



impl Send for Timespec



impl Send for std::sys::paths::unix::JoinPathsError



impl Send for CommandEnv



impl Send for CommandResolvedEnvs



impl Send for ChildPipes



impl Send for std::sys::process::unix::common::Command



impl Send for std::sys::process::unix::common::ExitCode



impl Send for std::sys::process::unix::unix::ExitStatus



impl Send for std::sys::process::unix::unix::ExitStatusError



impl Send for Process



impl Send for std::sys::stdio::unix::Stderr



impl Send for std::sys::stdio::unix::Stdin



impl Send for std::sys::stdio::unix::Stdout



impl Send for std::sys::sync::condvar::futex::Condvar



impl Send for std::sys::sync::mutex::futex::Mutex



impl Send for std::sys::sync::once::futex::Once



impl Send for std::sys::sync::once::futex::OnceState



impl Send for std::sys::sync::rwlock::futex::RwLock



impl Send for Parker



impl Send for std::sys::thread::unsupported::Thread



impl Send for LazyKey



impl Send for std::sys::time::unix::Instant



impl Send for std::sys::time::unix::SystemTime



impl Send for RawWakerVTable



impl Send for Builder



impl Send for PanicGuard



impl Send for ThreadId



impl Send for ThreadInit



impl Send for AccessError



impl Send for ScopeData



impl Send for ChildSpawnHooks



impl Send for SpawnHook



impl Send for SpawnHooks



impl Send for std::thread::thread::Inner



impl Send for std::thread::thread::Thread



impl Send for ThreadNameString



impl Send for Duration



impl Send for std::time::Instant



impl Send for std::time::SystemTime



impl Send for SystemTimeError



impl Send for TryFromFloatSecsError



impl Send for PhantomPinned



impl Send for SocketAddrCRepr



impl<'a> Send for BytesOrWideString<'a>



impl<'a> Send for AddressKind<'a>



impl<'a> Send for AncillaryData<'a>



impl<'a> Send for Component<'a>



impl<'a> Send for Prefix<'a>



impl<'a> Send for Utf8Pattern<'a>



impl<'a> Send for Object<'a>



impl<'a> Send for std::backtrace_rs::symbolize::gimli::Context<'a>



impl<'a> Send for SymbolName<'a>



impl<'a> Send for SplitPaths<'a>



impl<'a> Send for std::ffi::os_str::Display<'a>



impl<'a> Send for BorrowedCursor<'a>



impl<'a> Send for std::io::Guard<'a>



impl<'a> Send for std::net::tcp::Incoming<'a>



impl<'a> Send for Messages<'a>



impl<'a> Send for ScmCredentials<'a>



impl<'a> Send for ScmRights<'a>



impl<'a> Send for SocketAncillary<'a>



impl<'a> Send for std::os::unix::net::listener::Incoming<'a>



impl<'a> Send for Ancestors<'a>



impl<'a> Send for Components<'a>



impl<'a> Send for std::path::Display<'a>



impl<'a> Send for std::path::Iter<'a>



impl<'a> Send for PrefixComponent<'a>



impl<'a> Send for std::process::CommandEnvs<'a>



impl<'a> Send for EscapeAscii<'a>



impl<'a> Send for CharSearcher<'a>



impl<'a> Send for std::str::Bytes<'a>



impl<'a> Send for CharIndices<'a>



impl<'a> Send for Chars<'a>



impl<'a> Send for EncodeUtf16<'a>



impl<'a> Send for std::str::EscapeDebug<'a>



impl<'a> Send for std::str::EscapeDefault<'a>



impl<'a> Send for std::str::EscapeUnicode<'a>



impl<'a> Send for std::str::Lines<'a>



impl<'a> Send for LinesAny<'a>



impl<'a> Send for SplitAsciiWhitespace<'a>



impl<'a> Send for SplitWhitespace<'a>



impl<'a> Send for Utf8Chunk<'a>



impl<'a> Send for Utf8Chunks<'a>



impl<'a> Send for std::sys::process::env::CommandEnvs<'a>



impl<'a> Send for CompletionGuard<'a>



impl<'a> Send for PhantomContravariantLifetime<'a>



impl<'a> Send for PhantomCovariantLifetime<'a>



impl<'a> Send for PhantomInvariantLifetime<'a>



impl<'a, 'b> Send for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Send for StrSearcher<'a, 'b>



impl<'a, 'b, R, W> Send for Copier<'a, 'b, R, W>
where R: Send + ?Sized, W: Send + ?Sized,



impl<'a, 'b, const N: usize> Send for CharArrayRefSearcher<'a, 'b, N>



impl<'a, A> Send for std::option::Iter<'a, A>
where A: Sync,



impl<'a, A> Send for std::option::IterMut<'a, A>
where A: Send,



impl<'a, B> Send for Cow<'a, B>
where <B as ToOwned>::Owned: Send, B: Sync + ?Sized,



impl<'a, D> Send for Indented<'a, D>
where D: Send,



impl<'a, F> Send for CharPredicateSearcher<'a, F>
where F: Send,



impl<'a, I> Send for ByRefSized<'a, I>
where I: Send,



impl<'a, I, A> Send for std::collections::vec_deque::Splice<'a, I, A>
where I: Send, <I as Iterator>::Item: Send, A: Send,



impl<'a, I, A> Send for std::vec::Splice<'a, I, A>
where I: Send, <I as Iterator>::Item: Send, A: Send,



impl<'a, K> Send for std::collections::btree_set::Cursor<'a, K>
where K: Sync,



impl<'a, K> Send for std::collections::hash::set::Iter<'a, K>
where K: Sync,



impl<'a, K, A> Send for std::collections::btree_set::CursorMut<'a, K, A>
where A: Send, K: Send,



impl<'a, K, A> Send for std::collections::btree_set::CursorMutKey<'a, K, A>
where A: Send, K: Send,



impl<'a, K, A> Send for std::collections::hash::set::Drain<'a, K, A>
where A: Send, K: Send,



impl<'a, K, F, A> Send for std::collections::hash::set::ExtractIf<'a, K, F, A>
where F: Send, A: Send, K: Send,



impl<'a, K, V> Send for std::collections::btree_map::Cursor<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for std::collections::btree_map::Iter<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for std::collections::btree_map::IterMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V> Send for std::collections::btree_map::Keys<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for std::collections::btree_map::Range<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for RangeMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V> Send for std::collections::btree_map::Values<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for std::collections::btree_map::ValuesMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V> Send for std::collections::hash::map::Iter<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for std::collections::hash::map::IterMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V> Send for std::collections::hash::map::Keys<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for std::collections::hash::map::Values<'a, K, V>
where K: Sync, V: Sync,



impl<'a, K, V> Send for std::collections::hash::map::ValuesMut<'a, K, V>
where K: Send, V: Send,



impl<'a, K, V, A> Send for std::collections::btree_map::Entry<'a, K, V, A>
where K: Send, A: Send, V: Send,



impl<'a, K, V, A> Send for std::collections::hash::map::Entry<'a, K, V, A>
where K: Send, V: Send, A: Send,



impl<'a, K, V, A> Send for std::collections::btree_map::CursorMut<'a, K, V, A>
where A: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for std::collections::btree_map::CursorMutKey<'a, K, V, A>
where A: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for std::collections::btree_map::OccupiedEntry<'a, K, V, A>
where A: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for std::collections::btree_map::OccupiedError<'a, K, V, A>
where K: Send, V: Send, A: Send,



impl<'a, K, V, A> Send for std::collections::btree_map::VacantEntry<'a, K, V, A>
where K: Send, A: Send, V: Send,



impl<'a, K, V, A> Send for std::collections::hash::map::Drain<'a, K, V, A>
where A: Send, K: Send, V: Send,



impl<'a, K, V, A> Send for std::collections::hash::map::OccupiedEntry<'a, K, V, A>
where K: Send, V: Send, A: Send,



impl<'a, K, V, A> Send for std::collections::hash::map::OccupiedError<'a, K, V, A>
where K: Send, V: Send, A: Send,



impl<'a, K, V, A> Send for std::collections::hash::map::VacantEntry<'a, K, V, A>
where K: Send, A: Send, V: Send,



impl<'a, K, V, F, A> Send for std::collections::hash::map::ExtractIf<'a, K, V, F, A>
where F: Send, A: Send, K: Send, V: Send,



impl<'a, K, V, R, F, A> Send for std::collections::btree_map::ExtractIf<'a, K, V, R, F, A>
where F: Send, A: Send, R: Send, K: Send, V: Send,



impl<'a, P> Send for MatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for Matches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatchIndices<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RMatches<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for std::str::RSplit<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for std::str::RSplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for RSplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for std::str::Split<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for std::str::SplitInclusive<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for std::str::SplitN<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, P> Send for SplitTerminator<'a, P>
where <P as Pattern>::Searcher<'a>: Send,



impl<'a, T> Send for std::collections::binary_heap::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for std::collections::btree_set::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for std::collections::btree_set::Range<'a, T>
where T: Sync,



impl<'a, T> Send for std::collections::btree_set::SymmetricDifference<'a, T>
where T: Sync,



impl<'a, T> Send for std::collections::btree_set::Union<'a, T>
where T: Sync,



impl<'a, T> Send for std::collections::vec_deque::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for std::collections::vec_deque::IterMut<'a, T>
where T: Send,



impl<'a, T> Send for AncillaryDataIter<'a, T>
where T: Send,



impl<'a, T> Send for std::result::Iter<'a, T>
where T: Sync,



impl<'a, T> Send for std::result::IterMut<'a, T>
where T: Send,



impl<'a, T> Send for Chunks<'a, T>
where T: Sync,



impl<'a, T> Send for ChunksExact<'a, T>
where T: Sync,



impl<'a, T> Send for RChunks<'a, T>
where T: Sync,



impl<'a, T> Send for RChunksExact<'a, T>
where T: Sync,



impl<'a, T> Send for Windows<'a, T>
where T: Sync,



impl<'a, T> Send for std::sync::mpmc::Iter<'a, T>
where T: Send,



impl<'a, T> Send for std::sync::mpmc::TryIter<'a, T>
where T: Send,



impl<'a, T, A> Send for std::collections::btree_set::Entry<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for std::collections::binary_heap::Drain<'a, T, A>
where T: Send, A: Send,



impl<'a, T, A> Send for DrainSorted<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for std::collections::binary_heap::PeekMut<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for std::collections::btree_set::Difference<'a, T, A>
where T: Sync, A: Sync,



impl<'a, T, A> Send for std::collections::btree_set::Intersection<'a, T, A>
where T: Sync, A: Sync,



impl<'a, T, A> Send for std::collections::btree_set::OccupiedEntry<'a, T, A>
where A: Send, T: Send,



impl<'a, T, A> Send for std::collections::btree_set::VacantEntry<'a, T, A>
where T: Send, A: Send,



impl<'a, T, A> Send for std::vec::PeekMut<'a, T, A>
where A: Send, T: Send,



impl<'a, T, F, A> Send for std::collections::vec_deque::ExtractIf<'a, T, F, A>
where F: Send, A: Send, T: Send,



impl<'a, T, F, A> Send for std::vec::ExtractIf<'a, T, F, A>
where F: Send, A: Send, T: Send,



impl<'a, T, P> Send for ChunkBy<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for ChunkByMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for std::slice::RSplit<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for RSplitMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for std::slice::RSplitN<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for RSplitNMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for std::slice::Split<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for std::slice::SplitInclusive<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for SplitInclusiveMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for SplitMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, P> Send for std::slice::SplitN<'a, T, P>
where P: Send, T: Sync,



impl<'a, T, P> Send for SplitNMut<'a, T, P>
where P: Send, T: Send,



impl<'a, T, R, F, A> Send for std::collections::btree_set::ExtractIf<'a, T, R, F, A>
where F: Send, A: Send, R: Send, T: Send,



impl<'a, T, S, A> Send for std::collections::hash::set::Entry<'a, T, S, A>
where T: Send, S: Send, A: Send,



impl<'a, T, S, A> Send for std::collections::hash::set::Difference<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Send for std::collections::hash::set::Intersection<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Send for std::collections::hash::set::OccupiedEntry<'a, T, S, A>
where T: Send, S: Send, A: Send,



impl<'a, T, S, A> Send for std::collections::hash::set::SymmetricDifference<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Send for std::collections::hash::set::Union<'a, T, S, A>
where S: Sync, A: Sync, T: Sync,



impl<'a, T, S, A> Send for std::collections::hash::set::VacantEntry<'a, T, S, A>
where T: Send, S: Send, A: Send,



impl<'a, T, const N: usize> Send for ArrayWindows<'a, T, N>
where T: Sync,



impl<'a, W> Send for LineWriterShim<'a, W>
where W: Send + ?Sized,



impl<'a, const N: usize> Send for CharArraySearcher<'a, N>



impl<'data> Send for BorrowedBuf<'data>



impl<'fd> Send for BorrowedFd<'fd>



impl<'scope, 'env> Send for Scope<'scope, 'env>



impl<'scope, T> Send for JoinInner<'scope, T>
where T: Send,



impl<'scope, T> Send for std::thread::lifecycle::Packet<'scope, T>
where T: Send,



impl<'scope, T> Send for ScopedJoinHandle<'scope, T>
where T: Send,



impl<A> Send for std::iter::Repeat<A>
where A: Send,



impl<A> Send for RepeatN<A>
where A: Send,



impl<A> Send for std::option::IntoIter<A>
where A: Send,



impl<A> Send for OptionFlatten<A>
where A: Send,



impl<A> Send for RangeFromIter<A>
where A: Send,



impl<A> Send for RangeInclusiveIter<A>
where A: Send,



impl<A> Send for RangeIter<A>
where A: Send,



impl<A, B> Send for Either<A, B>
where A: Send, B: Send,



impl<A, B> Send for std::iter::Chain<A, B>
where A: Send, B: Send,



impl<A, B> Send for Zip<A, B>
where A: Send, B: Send,



impl<B> Send for std::io::Lines<B>
where B: Send,



impl<B> Send for std::io::Split<B>
where B: Send,



impl<B, C> Send for ControlFlow<B, C>
where C: Send, B: Send,



impl<C> Send for ErrorData<C>
where C: Send,



impl<C> Send for Counter<C>
where C: Send,



impl<D> Send for std::sys::thread_local::native::lazy::State<D>
where D: Send,



impl<E> Send for Report<E>
where E: Send,



impl<F> Send for std::fmt::FromFn<F>
where F: Send,



impl<F> Send for PollFn<F>
where F: Send,



impl<F> Send for std::iter::FromFn<F>
where F: Send,



impl<F> Send for OnceWith<F>
where F: Send,



impl<F> Send for RepeatWith<F>
where F: Send,



impl<F> Send for ExternWeak<F>
where F: Send,



impl<G> Send for FromCoroutine<G>
where G: Send,



impl<H> Send for BuildHasherDefault<H>



impl<I> Send for FromIter<I>
where I: Send,



impl<I> Send for DecodeUtf16<I>
where I: Send,



impl<I> Send for Cloned<I>
where I: Send,



impl<I> Send for Copied<I>
where I: Send,



impl<I> Send for Cycle<I>
where I: Send,



impl<I> Send for Enumerate<I>
where I: Send,



impl<I> Send for Flatten<I>
where <<I as Iterator>::Item as IntoIterator>::IntoIter: Send, I: Send,



impl<I> Send for Fuse<I>
where I: Send,



impl<I> Send for Intersperse<I>
where <I as Iterator>::Item: Sized + Send, I: Send,



impl<I> Send for Peekable<I>
where I: Send, <I as Iterator>::Item: Send,



impl<I> Send for Skip<I>
where I: Send,



impl<I> Send for StepBy<I>
where I: Send,



impl<I> Send for std::iter::Take<I>
where I: Send,



impl<I, F> Send for FilterMap<I, F>
where I: Send, F: Send,



impl<I, F> Send for Inspect<I, F>
where I: Send, F: Send,



impl<I, F> Send for Map<I, F>
where I: Send, F: Send,



impl<I, F, const N: usize> Send for MapWindows<I, F, N>
where F: Send, I: Send, <I as Iterator>::Item: Send,



impl<I, G> Send for IntersperseWith<I, G>
where G: Send, I: Send, <I as Iterator>::Item: Send,



impl<I, P> Send for Filter<I, P>
where I: Send, P: Send,



impl<I, P> Send for MapWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for SkipWhile<I, P>
where I: Send, P: Send,



impl<I, P> Send for TakeWhile<I, P>
where I: Send, P: Send,



impl<I, St, F> Send for Scan<I, St, F>
where I: Send, F: Send, St: Send,



impl<I, U, F> Send for FlatMap<I, U, F>
where <U as IntoIterator>::IntoIter: Send, I: Send, F: Send,



impl<I, const N: usize> Send for ArrayChunks<I, N>
where I: Send, <I as Iterator>::Item: Send,



impl<Idx> Send for std::ops::Range<Idx>
where Idx: Send,



impl<Idx> Send for std::ops::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for std::ops::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for RangeTo<Idx>
where Idx: Send,



impl<Idx> Send for std::ops::RangeToInclusive<Idx>
where Idx: Send,



impl<Idx> Send for std::range::Range<Idx>
where Idx: Send,



impl<Idx> Send for std::range::RangeFrom<Idx>
where Idx: Send,



impl<Idx> Send for std::range::RangeInclusive<Idx>
where Idx: Send,



impl<Idx> Send for std::range::RangeToInclusive<Idx>
where Idx: Send,



impl<K, A> Send for std::collections::hash::set::IntoIter<K, A>
where A: Send, K: Send,



impl<K, V, A> Send for std::collections::btree_map::IntoIter<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for std::collections::btree_map::IntoKeys<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for std::collections::btree_map::IntoValues<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for std::collections::hash::map::IntoIter<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for std::collections::hash::map::IntoKeys<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for std::collections::hash::map::IntoValues<K, V, A>
where A: Send, K: Send, V: Send,



impl<K, V, A> Send for BTreeMap<K, V, A>
where K: Send, V: Send, A: Send,



impl<K, V, S, A> Send for HashMap<K, V, S, A>
where S: Send, A: Send, K: Send, V: Send,



impl<P> Send for MaybeDangling<P>
where P: Send + ?Sized,



impl<Ptr> Send for Pin<Ptr>
where Ptr: Send,



impl<R> Send for BufReader<R>
where R: Send + ?Sized,



impl<R> Send for std::io::Bytes<R>
where R: Send,



impl<Ret, T> Send for fn(T₁, T₂, …, Tₙ) -> Ret



impl<T> Send for Bound<T>
where T: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for std::sync::TryLockError<T>
where T: Send,



impl<T> Send for SendTimeoutError<T>
where T: Send,



impl<T> Send for TrySendError<T>
where T: Send,



impl<T> Send for std::sync::oneshot::RecvTimeoutError<T>
where T: Send,



impl<T> Send for std::sync::oneshot::TryRecvError<T>
where T: Send,



impl<T> Send for Poll<T>
where T: Send,



impl<T> Send for [T]
where T: Send,



impl<T> Send for (T₁, T₂, …, Tₙ)
where T: Send,



impl<T> Send for OnceCell<T>
where T: Send,



impl<T> Send for SyncUnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for UnsafeCell<T>
where T: Send + ?Sized,



impl<T> Send for Reverse<T>
where T: Send,



impl<T> Send for Pending<T>



impl<T> Send for Ready<T>
where T: Send,



impl<T> Send for std::io::Cursor<T>
where T: Send,



impl<T> Send for std::io::Take<T>
where T: Send,



impl<T> Send for std::iter::Empty<T>



impl<T> Send for std::iter::Once<T>
where T: Send,



impl<T> Send for Rev<T>
where T: Send,



impl<T> Send for Discriminant<T>



impl<T> Send for ManuallyDrop<T>
where T: Send + ?Sized,



impl<T> Send for TraitImpl<T>
where T: ?Sized,



impl<T> Send for Saturating<T>
where T: Send,



impl<T> Send for Wrapping<T>
where T: Send,



impl<T> Send for Yeet<T>
where T: Send,



impl<T> Send for AssertUnwindSafe<T>
where T: Send,



impl<T> Send for UnsafePinned<T>
where T: Send + ?Sized,



impl<T> Send for std::result::IntoIter<T>
where T: Send,



impl<T> Send for std::sync::mpmc::array::Slot<T>
where T: Send,



impl<T> Send for Block<T>
where T: Send,



impl<T> Send for Position<T>



impl<T> Send for std::sync::mpmc::list::Slot<T>
where T: Send,



impl<T> Send for std::sync::mpmc::IntoIter<T>
where T: Send,



impl<T> Send for CachePadded<T>
where T: Send,



impl<T> Send for std::sync::mpmc::zero::Packet<T>
where T: Send,



impl<T> Send for std::sync::mpsc::IntoIter<T>
where T: Send,



impl<T> Send for SendError<T>
where T: Send,



impl<T> Send for std::sync::oneshot::Receiver<T>
where T: Send,



impl<T> Send for std::sync::oneshot::Sender<T>
where T: Send,



impl<T> Send for PoisonError<T>
where T: Send,



impl<T> Send for SyncView<T>
where T: Send + ?Sized,



impl<T> Send for std::sys::thread_local::native::eager::Storage<T>
where T: Send,



impl<T> Send for LocalKey<T>



impl<T> Send for PhantomContravariant<T>
where T: ?Sized,



impl<T> Send for PhantomCovariant<T>
where T: ?Sized,



impl<T> Send for PhantomData<T>
where T: Send + ?Sized,



impl<T> Send for PhantomInvariant<T>
where T: ?Sized,



impl<T> Send for MaybeUninit<T>
where T: Send,



impl<T, A> Send for Box<T, A>
where A: Send, T: Send + ?Sized,



impl<T, A> Send for std::collections::binary_heap::IntoIter<T, A>
where T: Send, A: Send,



impl<T, A> Send for IntoIterSorted<T, A>
where A: Send, T: Send,



impl<T, A> Send for std::collections::btree_set::IntoIter<T, A>
where A: Send, T: Send,



impl<T, A> Send for std::collections::linked_list::IntoIter<T, A>
where T: Send, A: Send,



impl<T, A> Send for BTreeSet<T, A>
where T: Send, A: Send,



impl<T, A> Send for BinaryHeap<T, A>
where A: Send, T: Send,



impl<T, A> Send for VecDeque<T, A>
where A: Send, T: Send,



impl<T, A> Send for std::collections::vec_deque::IntoIter<T, A>
where A: Send, T: Send,



impl<T, A> Send for Vec<T, A>
where A: Send, T: Send,



impl<T, D> Send for std::sys::thread_local::native::lazy::Storage<T, D>
where D: Send, T: Send,



impl<T, E> Send for Result<T, E>
where T: Send, E: Send,



impl<T, F> Send for LazyCell<T, F>
where F: Send, T: Send,



impl<T, F> Send for Successors<T, F>
where F: Send, T: Send,



impl<T, F> Send for DropGuard<T, F>
where T: Send, F: Send,



impl<T, F> Send for LazyLock<T, F>
where T: Send, F: Send,



impl<T, F> Send for Data<T, F>
where T: Send, F: Send,



impl<T, S, A> Send for HashSet<T, S, A>
where S: Send, A: Send, T: Send,



impl<T, U> Send for std::io::Chain<T, U>
where T: Send, U: Send,



impl<T, const N: usize> Send for [T; N]
where T: Send,



impl<T, const N: usize> Send for std::array::IntoIter<T, N>
where T: Send,



impl<T, const N: usize> Send for Lru<T, N>
where T: Send,



impl<T, const N: usize> Send for Mask<T, N>
where T: Send,



impl<T, const N: usize> Send for Simd<T, N>
where T: Send,



impl<T, const N: usize> Send for [Option<T>; N]
where T: Send,



impl<T, const N: usize> Send for [MaybeUninit<T>; N]
where T: Send,



impl<T, const VARIANT: u32, const FIELD: u32> Send for FieldRepresentingType<T, VARIANT, FIELD>
where T: ?Sized,



impl<W> Send for BufWriter<W>
where W: Send + ?Sized,



impl<W> Send for LineWriter<W>
where W: Send + ?Sized,



impl<W> Send for IntoInnerError<W>
where W: Send,



impl<Y, R> Send for CoroutineState<Y, R>
where Y: Send, R: Send,



impl<const N: usize> Send for [u8; N]